@@ -38,5 +38,16 @@ def make_driver_template(name, from_package):
         os.system(f'rm {last.text}')
         folder = last.text.replace('.tar.gz','')
         os.system(f'mv {folder} {name}')
+        version = folder.rsplit('-', 1)[-1]
 
     # 3. Find and replace
+        os.system(f'rm {name}/PKG-INFO')
+        os.system(f'rm {name}/setup.cfg')
+        os.system(f'rm -rf {name}/{from_package}.egg-info')
+        os.system(f'mv {name}/{from_package} {name}/{name}')
+        os.system(f"sed -i 's/{from_package}/{name}/g' setup.py")
+        # Renaming inside files
+        os.system(f"sed -i 's/{from_package}/{name}/g' {name}/setup.py")
+        os.system(f"sed -i 's/{version}/0.0.0/g' {name}/setup.py")
+        os.system(f"sed -i 's/{from_package}/{name}/g' {name}/README.md")
+        os.system(f"sed -i 's/{from_package}/{name}/g' {name}/{name}/main.py")
